# prawscripts

This is simply a test concept/idea for merging together all public scripts we have and putting a wrapper for it,  
given permission from the original author. For now, only two functions are created:

* getinstance
* makewidget

Installation package at https://pypi.org/project/prawscripts/0.0.3/

The main dependency should mainly just be PRAW at this time.

Open to contributors from r/ModGuide for uploading/reuploading new/existing functions and testing if package is  
working properly.
